DocumentView

Enum DocumentView 

pub enum DocumentView {
    All {
        ignored_types: Option<Vec<SecretType>>,
    },
    Vault(VaultId),
    TypeId(SecretType),
    Favorites,
    Tags(Vec<String>),
    Contact {
        include_types: Option<Vec<Kind>>,
    },
    Documents {
        folder_id: VaultId,
        identifiers: Vec<SecretId>,
    },
    Websites {
        matches: Option<Vec<Url>>,
        exact: bool,
    },
}
View of documents in the search index.

Variants



All

View all documents in the search index.

Fields

ignored_types: Option<Vec<SecretType>>

List of secret types to ignore.



Vault(VaultId)

View all the documents for a folder.



TypeId(SecretType)

View documents across all vaults by type identifier.



Favorites

View for all favorites.



Tags(Vec<String>)

View documents that have one or more tags.



Contact

Contacts of the given types.

Fields

include_types: Option<Vec<Kind>>

Contact types to include in the results.

If no types are specified all types are included.



Documents

Documents with the specific identifiers.

Fields

folder_id: VaultId

Vault identifier.

identifiers: Vec<SecretId>

Secret identifiers.



Websites

Secrets with the associated websites.

Fields

matches: Option<Vec<Url>>

Secrets that match the given target URLs.

exact: bool

Exact match requires that the match targets and websites are exactly equal. Otherwise, comparison is performed using the URL origin.

Implementations

Source

impl DocumentView

pub fn test(&self, doc: &Document, archive: Option<&ArchiveFilter>) -> bool

Test this view against a search result document.